import { API as ParentAPI } from '../../../bridge';
import type { Region as ScwRegion } from '../../../bridge';
import type { AttachIPRequest, BookIPRequest, DetachIPRequest, GetIPRequest, IP, ListIPsRequest, ListIPsResponse, MoveIPRequest, ReleaseIPRequest, ReleaseIPSetRequest, UpdateIPRequest } from './types.gen';
/**
 * IPAM API.
 *
 * This API allows you to manage your Scaleway IP addresses with our IP Address
 * Management tool.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: ScwRegion[];
    /**
     * Reserve a new IP. Reserve a new IP from the specified source. Currently IPs
     * can only be reserved from a Private Network.
     *
     * @param request - The request {@link BookIPRequest}
     * @returns A Promise of IP
     */
    bookIP: (request: Readonly<BookIPRequest>) => Promise<IP>;
    /**
     * Release an IP. Release an IP not currently attached to a resource, and
     * returns it to the available IP pool.
     *
     * @param request - The request {@link ReleaseIPRequest}
     */
    releaseIP: (request: Readonly<ReleaseIPRequest>) => Promise<void>;
    releaseIPSet: (request?: Readonly<ReleaseIPSetRequest>) => Promise<void>;
    /**
     * Get an IP. Retrieve details of an existing IP, specified by its IP ID.
     *
     * @param request - The request {@link GetIPRequest}
     * @returns A Promise of IP
     */
    getIP: (request: Readonly<GetIPRequest>) => Promise<IP>;
    /**
     * Update an IP. Update parameters including tags of the specified IP.
     *
     * @param request - The request {@link UpdateIPRequest}
     * @returns A Promise of IP
     */
    updateIP: (request: Readonly<UpdateIPRequest>) => Promise<IP>;
    protected pageOfListIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse>;
    /**
     * List existing IPs. List existing IPs in the specified region using various
     * filters. For example, you can filter for IPs within a specified Private
     * Network, or for public IPs within a specified Project. By default, the IPs
     * returned in the list are ordered by creation date in ascending order,
     * though this can be modified via the order_by field.
     *
     * @param request - The request {@link ListIPsRequest}
     * @returns A Promise of ListIPsResponse
     */
    listIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse> & {
        all: () => Promise<IP[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<IP[], void, void>;
    };
    /**
     * Attach IP to custom resource. Attach an existing reserved IP from a Private
     * Network subnet to a custom, named resource via its MAC address. An example
     * of a custom resource is a virtual machine hosted on an Elastic Metal
     * server. Do not use this method for attaching IP addresses to standard
     * Scaleway resources as it will fail - see the relevant product API for an
     * equivalent method.
     *
     * @param request - The request {@link AttachIPRequest}
     * @returns A Promise of IP
     */
    attachIP: (request: Readonly<AttachIPRequest>) => Promise<IP>;
    /**
     * Detach IP from a custom resource. Detach a private IP from a custom
     * resource. An example of a custom resource is a virtual machine hosted on an
     * Elastic Metal server. Do not use this method for detaching IP addresses
     * from standard Scaleway resources (e.g. Instances, Load Balancers) as it
     * will fail - see the relevant product API for an equivalent method.
     *
     * @param request - The request {@link DetachIPRequest}
     * @returns A Promise of IP
     */
    detachIP: (request: Readonly<DetachIPRequest>) => Promise<IP>;
    /**
     * Move IP to a custom resource. Move an existing reserved private IP from one
     * custom resource (e.g. a virtual machine hosted on an Elastic Metal server)
     * to another custom resource. This will detach it from the first resource,
     * and attach it to the second. Do not use this method for moving IP addresses
     * between standard Scaleway resources (e.g. Instances, Load Balancers) as it
     * will fail - see the relevant product API for an equivalent method.
     *
     * @param request - The request {@link MoveIPRequest}
     * @returns A Promise of IP
     */
    moveIP: (request: Readonly<MoveIPRequest>) => Promise<IP>;
}
